@@ -7,7 +7,7 @@
 import copy
 
 from pyxllib.algo.pupil import intersection_split
-from pyxllib.algo.specialist import SetCmper
+from pyxllib.algo.specialist import DictCmper
 from pyxllib.debug.pupil import dprint, prettifystr
 from pyxllib.debug.specialist.browser import Explorer
 from pyxllib.file.specialist import File, Dir, filesmatch
